pub trait Score { // Required method fn score(&self) -> f32; }
Calculates a relative value “score” for an item which relates to how likely it is the item represents text.
This value can be used to determine the likeliness of the item representing text.
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".